==> jc-1.4.0.tar.gz: soot/grimp/internal/ObjExprBox.h <==
// public class soot.grimp.internal.ObjExprBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class 6082d80e94933a95 soot_grimp_internal_ExprBox
// @dep_class e4a9f6bb51f625c soot_grimp_internal_ObjExprBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_grimp_internal_ExprBox

#include "soot/grimp/internal/ExprBox.h"

#ifndef _JC_soot_grimp_internal_ObjExprBox_H_
#define _JC_soot_grimp_internal_ObjExprBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_ObjExprBox$sub_refs	_jc_soot_grimp_internal_ObjExprBox$sub_refs;
typedef struct _jc_soot_grimp_internal_ObjExprBox$sub_nonrefs	_jc_soot_grimp_internal_ObjExprBox$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_ObjExprBox$refs	_jc_soot_grimp_internal_ObjExprBox$refs;
typedef struct _jc_soot_grimp_internal_ObjExprBox$nonrefs	_jc_soot_grimp_internal_ObjExprBox$nonrefs;
typedef struct _jc_soot_grimp_internal_ObjExprBox$object	_jc_soot_grimp_internal_ObjExprBox$object;

typedef const struct _jc_soot_grimp_internal_ObjExprBox$vmethods	_jc_soot_grimp_internal_ObjExprBox$vmethods;
typedef const struct _jc_soot_grimp_internal_ObjExprBox$vtable	_jc_soot_grimp_internal_ObjExprBox$vtable;
typedef const struct _jc_soot_grimp_internal_ObjExprBox$vtype	_jc_soot_grimp_internal_ObjExprBox$vtype;

// Constructors
extern void _jc_soot_grimp_internal_ObjExprBox$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_ObjExprBox$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_grimp_internal_ObjExprBox$method$canContainValue$dd22978795c5cdfb(_jc_env *, struct _jc_soot_grimp_internal_ObjExprBox$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_ObjExprBox$method_info$canContainValue$dd22978795c5cdfb;

// Virtual methods structure
struct _jc_soot_grimp_internal_ObjExprBox$vmethods {
	jboolean	(*canContainValue$dd22978795c5cdfb)(_jc_env *, struct _jc_soot_grimp_internal_ObjExprBox$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_grimp_internal_ObjExprBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_grimp_internal_ExprBox$vmethods	soot_grimp_internal_ExprBox;
	_jc_soot_grimp_internal_ObjExprBox$vmethods	soot_grimp_internal_ObjExprBox;
};

// Vtype
struct _jc_soot_grimp_internal_ObjExprBox$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_ObjExprBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_ObjExprBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_ObjExprBox$refs {
    _jc_soot_grimp_internal_ObjExprBox$sub_refs	soot_grimp_internal_ObjExprBox;
    _jc_soot_grimp_internal_ExprBox$sub_refs	soot_grimp_internal_ExprBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_ObjExprBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_ObjExprBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_grimp_internal_ExprBox$sub_nonrefs	soot_grimp_internal_ExprBox;
    _jc_soot_grimp_internal_ObjExprBox$sub_nonrefs	soot_grimp_internal_ObjExprBox;
};

// Object instance structure
struct _jc_soot_grimp_internal_ObjExprBox$object {
	_jc_soot_grimp_internal_ObjExprBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_ObjExprBox$vtype	*vtype;
	_jc_soot_grimp_internal_ObjExprBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_ObjExprBox$vtype _jc_soot_grimp_internal_ObjExprBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_ObjExprBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_ObjExprBox$class_object;

#endif	/* _JC_soot_grimp_internal_ObjExprBox_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/ObjExprBox.h <==
// public class soot.grimp.internal.ObjExprBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class 6082d80e94933a95 soot_grimp_internal_ExprBox
// @dep_class e4a9f6bb51f625c soot_grimp_internal_ObjExprBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_grimp_internal_ExprBox

#include "soot/grimp/internal/ExprBox.h"

#ifndef _JC_soot_grimp_internal_ObjExprBox_H_
#define _JC_soot_grimp_internal_ObjExprBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_ObjExprBox$sub_refs	_jc_soot_grimp_internal_ObjExprBox$sub_refs;
typedef struct _jc_soot_grimp_internal_ObjExprBox$sub_nonrefs	_jc_soot_grimp_internal_ObjExprBox$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_ObjExprBox$refs	_jc_soot_grimp_internal_ObjExprBox$refs;
typedef struct _jc_soot_grimp_internal_ObjExprBox$nonrefs	_jc_soot_grimp_internal_ObjExprBox$nonrefs;
typedef struct _jc_soot_grimp_internal_ObjExprBox$object	_jc_soot_grimp_internal_ObjExprBox$object;

typedef const struct _jc_soot_grimp_internal_ObjExprBox$vmethods	_jc_soot_grimp_internal_ObjExprBox$vmethods;
typedef const struct _jc_soot_grimp_internal_ObjExprBox$vtable	_jc_soot_grimp_internal_ObjExprBox$vtable;
typedef const struct _jc_soot_grimp_internal_ObjExprBox$vtype	_jc_soot_grimp_internal_ObjExprBox$vtype;

// Constructors
extern void _jc_soot_grimp_internal_ObjExprBox$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_ObjExprBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_grimp_internal_ObjExprBox$method$canContainValue$dd22978795c5cdfb(_jc_env *, struct _jc_soot_grimp_internal_ObjExprBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_ObjExprBox$method_info$canContainValue$dd22978795c5cdfb;

// Virtual methods structure
struct _jc_soot_grimp_internal_ObjExprBox$vmethods {
	jboolean	(*canContainValue$dd22978795c5cdfb)(_jc_env *, struct _jc_soot_grimp_internal_ObjExprBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_ObjExprBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_grimp_internal_ExprBox$vmethods	soot_grimp_internal_ExprBox;
	_jc_soot_grimp_internal_ObjExprBox$vmethods	soot_grimp_internal_ObjExprBox;
};

// Vtype
struct _jc_soot_grimp_internal_ObjExprBox$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_ObjExprBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_ObjExprBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_ObjExprBox$refs {
    _jc_soot_grimp_internal_ObjExprBox$sub_refs	soot_grimp_internal_ObjExprBox;
    _jc_soot_grimp_internal_ExprBox$sub_refs	soot_grimp_internal_ExprBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_ObjExprBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_ObjExprBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_grimp_internal_ExprBox$sub_nonrefs	soot_grimp_internal_ExprBox;
    _jc_soot_grimp_internal_ObjExprBox$sub_nonrefs	soot_grimp_internal_ObjExprBox;
};

// Object instance structure
struct _jc_soot_grimp_internal_ObjExprBox$object {
	_jc_soot_grimp_internal_ObjExprBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_ObjExprBox$vtype	*vtype;
	_jc_soot_grimp_internal_ObjExprBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_ObjExprBox$vtype _jc_soot_grimp_internal_ObjExprBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_ObjExprBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_ObjExprBox$class_object;

#endif	/* _JC_soot_grimp_internal_ObjExprBox_H_ */
